window.Gleam.initSearch([{"doc":"gleam_httpc","title":"gleam_httpc","content":"# httpc\n&lt;a href=&quot;https://github.com/gleam-lang/httpc/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/gleam-lang/httpc&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt;\n&lt;a href=&quot;https://discord.gg/Fm8Pwmy&quot;&gt;&lt;img src=&quot;https://img.shields.io/discord/768594524158427167?color=blue&quot; alt=&quot;Discord chat&quot;&gt;&lt;/a&gt;\n![CI](https://github.com/gleam-lang/httpc/workflows/test/badge.svg?branch=main)\n\nBindings to Erlang&#39;s built in HTTP client, `httpc`.\n\n```shell\ngleam add gleam_httpc@4\n```\n```gleam\nimport gleam/http/request\nimport gleam/http/response\nimport gleam/httpc\nimport gleam/result\nimport gleeunit/should\n\npub fn send_request() {\n  // Prepare a HTTP request record\n  let assert Ok(base_req) =\n    request.to(&quot;https://test-api.service.hmrc.gov.uk/hello/world&quot;)\n\n  let req =\n    request.prepend_header(base_req, &quot;accept&quot;, &quot;application/vnd.hmrc.1.0+json&quot;)\n\n  // Send the HTTP request to the server\n  use resp &lt;- result.try(httpc.send(req))\n\n  // We get a response record back\n  resp.status\n  |&gt; should.equal(200)\n\n  resp\n  |&gt; response.get_header(&quot;content-type&quot;)\n  |&gt; should.equal(Ok(&quot;application/json&quot;))\n\n  resp.body\n  |&gt; should.equal(&quot;{\\&quot;message\\&quot;:\\&quot;Hello World\\&quot;}&quot;)\n\n  Ok(resp)\n}\n```\n\n## Use with Erlang/OTP versions older than 26.0\n\nOlder versions of HTTPC do not verify TLS connections by default, so with them\nyour connection may not be secure when using this library. Consider upgrading to\na newer version of Erlang/OTP, or using a different HTTP client such as\n[hackney](https://github.com/gleam-lang/hackney).\n","url":"index.html"},{"doc":"gleam/httpc","title":"Configuration","content":"pub opaque type Configuration\n Configuration that can be used to send HTTP requests.\n\n To be used with `dispatch` and `dispatch_bits`.\n\n\nSynonyms:\ngleam/httpc.Configuration\ngleam/httpc Configuration","url":"gleam/httpc.html#Configuration"},{"doc":"gleam/httpc","title":"ConnectError","content":"pub type ConnectError {\n  Posix(code: String)\n  TlsAlert(code: String, detail: String)\n}\n\nPosix(code: String)\n\n\nTlsAlert(code: String, detail: String)\n\n\nSynonyms:\ngleam/httpc.ConnectError\ngleam/httpc ConnectError","url":"gleam/httpc.html#ConnectError"},{"doc":"gleam/httpc","title":"HttpError","content":"pub type HttpError {\n  InvalidUtf8Response\n  FailedToConnect(ip4: ConnectError, ip6: ConnectError)\n}\n\nInvalidUtf8Response\n\n\nFailedToConnect(ip4: ConnectError, ip6: ConnectError)\n\n\nSynonyms:\ngleam/httpc.HttpError\ngleam/httpc HttpError","url":"gleam/httpc.html#HttpError"},{"doc":"gleam/httpc","title":"configure","content":"pub fn configure() -&gt; Configuration\n Create a new configuration with the default settings.\n\nSynonyms:\ngleam/httpc.configure\ngleam/httpc configure","url":"gleam/httpc.html#configure"},{"doc":"gleam/httpc","title":"dispatch","content":"pub fn dispatch(\n  config: Configuration,\n  request: Request(String),\n) -&gt; Result(Response(String), HttpError)\n Send a HTTP request of unicode data.\n\nSynonyms:\ngleam/httpc.dispatch\ngleam/httpc dispatch","url":"gleam/httpc.html#dispatch"},{"doc":"gleam/httpc","title":"dispatch_bits","content":"pub fn dispatch_bits(\n  config: Configuration,\n  req: Request(BitArray),\n) -&gt; Result(Response(BitArray), HttpError)\n Send a HTTP request of binary data.\n\nSynonyms:\ngleam/httpc.dispatch_bits\ngleam/httpc dispatch_bits","url":"gleam/httpc.html#dispatch_bits"},{"doc":"gleam/httpc","title":"send","content":"pub fn send(\n  req: Request(String),\n) -&gt; Result(Response(String), HttpError)\n Send a HTTP request of unicode data using the default configuration.\n\n If you wish to use some other configuration use `dispatch` instead.\n\nSynonyms:\ngleam/httpc.send\ngleam/httpc send","url":"gleam/httpc.html#send"},{"doc":"gleam/httpc","title":"send_bits","content":"pub fn send_bits(\n  req: Request(BitArray),\n) -&gt; Result(Response(BitArray), HttpError)\n Send a HTTP request of binary data using the default configuration.\n\n If you wish to use some other configuration use `dispatch_bits` instead.\n\nSynonyms:\ngleam/httpc.send_bits\ngleam/httpc send_bits","url":"gleam/httpc.html#send_bits"},{"doc":"gleam/httpc","title":"verify_tls","content":"pub fn verify_tls(\n  config: Configuration,\n  which: Bool,\n) -&gt; Configuration\n Set whether to verify the TLS certificate of the server.\n\n This defaults to `True`, meaning that the TLS certificate will be verified\n unless you call this function with `False`.\n\n Setting this to `False` can make your application vulnerable to\n man-in-the-middle attacks and other security risks. Do not do this unless\n you are sure and you understand the risks.\n\nSynonyms:\ngleam/httpc.verify_tls\ngleam/httpc verify_tls","url":"gleam/httpc.html#verify_tls"},{"doc":"gleam/httpc","title":"gleam/httpc","content":"","url":"gleam/httpc.html"}]);